<?php
/**
 * Capability definitions for the shared activities format.
 * 
 * For naming conventions, see lib/db/access.php.
 */
$format_sharedactv_capabilities = array(

    // Means you can view your shared activities. Required on the shared 
    // activity course. Usually assigned to logged-in user at site level.
    // This capability is also required in order for somebody to be invited
    // to a shared activity i.e. you can't invite somebody who doesn't have
    // this permission. 
    'format/sharedactv:view' => array(

        'riskbitmask' => 0,

        'captype' => 'read',
        'contextlevel' => CONTEXT_SYSTEM,
        'legacy' => array(
            'user' => CAP_ALLOW
        )
    ),

    // Means you can create shared activities. Required on the shared activity
    // course. Usually assigned to logged-in user at site level. 
    'format/sharedactv:create' => array(

        'riskbitmask' => RISK_SPAM,

        'captype' => 'write',
        'contextlevel' => CONTEXT_SYSTEM,
        'legacy' => array(
            'user' => CAP_ALLOW
        )
    ),

    // Means you can manage a shared activity. Manage includes editing the 
    // settings of the activity, inviting/removing users, and deleting it. 
    // Usually assigned via the 'shared activity creator' role at activity 
    // level. Can also be assigned to helpdesk staff (or obviously admin 
    // already have it) at site or shared activity course level, in order to 
    // allow them to manage all activities.  
    'format/sharedactv:manage' => array(

        'riskbitmask' => RISK_SPAM,

        'captype' => 'write',
        'contextlevel' => CONTEXT_SYSTEM,
        'legacy' => array(
            'admin' => CAP_ALLOW
        )
    ),

    // Means you can view somebody else's shared activity list. Usually would
    // be admin-only or assigned to Helpdesk etc
    'format/sharedactv:viewother' => array(

        'riskbitmask' => RISK_PERSONAL,

        'captype' => 'read',
        'contextlevel' => CONTEXT_SYSTEM,
        'legacy' => array(
            'admin' => CAP_ALLOW
        )
    )
);
