<?php
global $CFG;

require_once($CFG->libdir. '/simpletestlib/unit_tester.php');
require_once($CFG->libdir. '/simpletestlib.php');

require_once(dirname(__FILE__).'/../sharedactv.php');

class test_sharedactv extends UnitTestCase {

    function test_everything() {
        // Put everything in a transaction because we do this test on the
        // real database so we want to roll it back at the end
        $tw=new transaction_wrapper();

        // Create a pair of new users for testing
        $u1=(object)array('firstname'=>addslashes('Test\'1'),'lastname'=>'Shared-Activities',
        		'username'=>'sharedactv1');
        $u2=(object)array('firstname'=>addslashes('Test\'[2'),'lastname'=>'Shared-Activities',
        		'username'=>'sharedactv2');
        if(!insert_record('user',$u1) || !insert_record('user',$u2)) {
            throw new Exception('Ooops');
        }
        // Get records to remove slashes
        $u1=get_record('user','id',$u1->id);
        $u2=get_record('user','id',$u2->id);

        // Rock on. Now let's try getting the course...
        $magiccourse=sharedactv_get_magic_course();

        // Get the roles
        $roles=sharedactv_get_participant_roles();
        $this->assertEqual(count($roles),2);
        $this->assertEqual(array_keys($roles),
            array(SHAREDACTV_ROLE_PARTICIPANT,SHAREDACTV_ROLE_CREATOR));

        // Get shared activities for user 1 (there aren't any)
        $a1=sharedactv_get_shared_activities($u1->id);
        $this->assert_activities($a1,array(),array());

        // Before creating activities let's count rows in certain tables
        $countforum=count_records('forum');
        $countwiki=count_records('ouwiki');
        $countcm=count_records('course_modules');
        $countra=count_records('role_assignments');

        // Create an activity, fail condition then successful
        try {
            sharedactv_create_activity('zombie','My favourite zombie','Summary');
        } catch(Exception $e) {
            $this->assertEqual($e->getMessage(),
                'error() call: sharedactv_create_activity called with unsupported activity type');
        }

        // Make it create an activity on behalf of each user
        $cmid1=sharedactv_create_activity('forum',"Forum's fun","Forum's summarised",$u1->id);
        $cmid1b=sharedactv_create_activity('ouwiki',"Alphawiki",".",$u1->id);
        $cmid2=sharedactv_create_activity('ouwiki',"Wiki 2","x",$u2->id);

        // Test activity values
        $cm=get_record('course_modules','id',$cmid1);
        $this->assertEqual($cm->course,$magiccourse->id);
        $this->assertEqual($cm->module,get_field('modules','id','name','forum'));
        $this->assertTrue(get_record('forum','id',$cm->instance));
        $this->assertEqual($cm->visible,1);
        $this->assertEqual($cm->groupmode,0);
        $this->assertEqual($cm->groupingid,0);
        $this->assertEqual($cm->groupmembersonly,0);

        // Get shared activities for user 1 again
        $a1=sharedactv_get_shared_activities($u1->id);
        $this->assert_activities($a1,array($cmid1b,$cmid1),array()); // Alphabetical ordering should make 1b come first

        // Test added activity details
        $this->assertEqual($a1[SHAREDACTV_ROLE_CREATOR][$cmid1]->name,"Forum's fun");
        $this->assertEqual($a1[SHAREDACTV_ROLE_CREATOR][$cmid1]->moduletype,"forum");

        // Get the list of participants in first activity (just creator)
        $p1=sharedactv_get_participants($cmid1);
        $this->assert_participants($p1,array($u1->id),array());
        $this->assertEqual($p1[SHAREDACTV_ROLE_CREATOR][$u1->id]->firstname,$u1->firstname);
        $this->assertEqual($p1[SHAREDACTV_ROLE_CREATOR][$u1->id]->lastname,$u1->lastname);
        $this->assertEqual($p1[SHAREDACTV_ROLE_CREATOR][$u1->id]->username,$u1->username);

        // Invite user 1 to user 2's activity
        $this->assertTrue(sharedactv_add_participant($cmid2,$u1->id));
        $p2=sharedactv_get_participants($cmid2);
        $this->assert_participants($p2,array($u2->id),array($u1->id));
        $this->assertEqual($p2[SHAREDACTV_ROLE_PARTICIPANT][$u1->id]->firstname,$u1->firstname);
        $this->assertEqual($p2[SHAREDACTV_ROLE_PARTICIPANT][$u1->id]->lastname,$u1->lastname);
        $this->assertEqual($p2[SHAREDACTV_ROLE_PARTICIPANT][$u1->id]->username,$u1->username);
        
        // Check the participants variant that only returns one role
        $p2p=sharedactv_get_participants($cmid2,SHAREDACTV_ROLE_PARTICIPANT);
        $this->assertEqual(count($p2p),1);
        $this->assertEqual($p2p[$u1->id]->id,$u1->id);
        $p2c=sharedactv_get_participants($cmid2,SHAREDACTV_ROLE_CREATOR);
        $this->assertEqual(count($p2c),1);
        $this->assertEqual($p2c[$u2->id]->id,$u2->id);        

        // Get shared activities for user 1 again
        $a1=sharedactv_get_shared_activities($u1->id);
        $this->assert_activities($a1,array($cmid1b,$cmid1),array($cmid2));

        // Uninvite user 1
        $this->assertTrue(sharedactv_remove_participant($cmid2,$u1->id));
        $p2=sharedactv_get_participants($cmid2);
        $this->assert_participants($p2,array($u2->id),array());
        
        // Test activity info
        $this->assertEqual(sharedactv_get_activity_info($cmid1),(object)array(
            'moduletype'=>'forum','name'=>"Forum's fun",
            'summary'=>"Forum's summarised",'id'=>$cmid1));
        $this->assertEqual(sharedactv_get_activity_info($cmid1b),(object)array(
            'moduletype'=>'ouwiki','name'=>"Alphawiki",
            'summary'=>".",'id'=>$cmid1b));
        $this->assertEqual(sharedactv_get_activity_info($cmid2),(object)array(
            'moduletype'=>'ouwiki','name'=>"Wiki 2",
            'summary'=>"x",'id'=>$cmid2));
        
        // Test set activity info
        sharedactv_set_activity_info($cmid2,'What\'s up?','Why\'s that?');
        $this->assertEqual(sharedactv_get_activity_info($cmid2),(object)array(
            'moduletype'=>'ouwiki','name'=>"What's up?",
            'summary'=>"Why's that?",'id'=>$cmid2));
        sharedactv_set_activity_info($cmid1,'What\'s up?','Why\'s that?');
        $this->assertEqual(sharedactv_get_activity_info($cmid1),(object)array(
            'moduletype'=>'forum','name'=>"What's up?",
            'summary'=>"Why's that?",'id'=>$cmid1));
        
        // Delete activities
        sharedactv_delete_activity(get_record('course_modules','id',$cmid1));
        sharedactv_delete_activity(get_record('course_modules','id',$cmid1b));
        sharedactv_delete_activity(get_record('course_modules','id',$cmid2));

        // Before creating activities let's count rows in certain tables
        $this->assertEqual($countforum,count_records('forum'));
        $this->assertEqual($countwiki,count_records('ouwiki'));
        $this->assertEqual($countcm,count_records('course_modules'));
        $this->assertEqual($countra,count_records('role_assignments'));

        $tw->rollback();
    }

    function assert_participants($p,$creators,$participants) {
        $this->assertEqual(count($p),2);
        $this->assertEqual(array_keys($p),array(
        	SHAREDACTV_ROLE_CREATOR,SHAREDACTV_ROLE_PARTICIPANT));
        $this->assertEqual(array_keys($p[SHAREDACTV_ROLE_CREATOR]),$creators);
        $this->assertEqual(array_keys($p[SHAREDACTV_ROLE_PARTICIPANT]),$participants);
    }

    function assert_activities($a,$owned,$invited) {
        $this->assertEqual(count($a),2);
        $this->assertEqual(array_keys($a),array(
        	SHAREDACTV_ROLE_CREATOR,SHAREDACTV_ROLE_PARTICIPANT));
        $this->assertEqual(array_keys($a[SHAREDACTV_ROLE_CREATOR]),$owned);
        $this->assertEqual(array_keys($a[SHAREDACTV_ROLE_PARTICIPANT]),$invited);
    }

}
?>
